@@ -2,10 +2,9 @@
 
 use crate::{
     constants::{
-        RClass, RType, DOMAIN_NAME_LABEL_MAX_LENGTH, DOMAIN_NAME_MAX_LENGTH,
-        DOMAIN_NAME_MAX_POINTERS,
+        Class, Type, DOMAIN_NAME_LABEL_MAX_LENGTH, DOMAIN_NAME_MAX_LENGTH, DOMAIN_NAME_MAX_POINTERS,
     },
-    message::{MessageType, OperationCode, RecordClass, RecordType, ResponseCode},
+    message::{ClassValue, MessageType, OpCodeValue, RCodeValue, TypeValue},
 };
 
 /// Errors returned by [rsdns](crate).
@@ -16,20 +15,20 @@ pub enum Error {
     #[error("io error")]
     IoError(#[from] std::io::Error),
 
-    #[error("unrecognized record type: {0}")]
-    UnrecognizedRecordType(RecordType),
+    #[error("unknown type: {0}")]
+    UnknownType(TypeValue),
 
-    #[error("RTYPE {0} is not expected")]
-    UnexpectedRType(RType),
+    #[error("TYPE {0} is not expected")]
+    UnexpectedType(Type),
 
-    #[error("reserved resource record class: {0}")]
-    UnrecognizedRecordClass(RecordClass),
+    #[error("unknown class: {0}")]
+    UnknownClass(ClassValue),
 
-    #[error("unrecognized operation code: {0}")]
-    UnrecognizedOperationCode(OperationCode),
+    #[error("unknown operation code: {0}")]
+    UnknownOpCode(OpCodeValue),
 
-    #[error("reserved response code: {0}")]
-    UnrecognizedResponseCode(ResponseCode),
+    #[error("unknown response code: {0}")]
+    UnknownRCode(RCodeValue),
 
     #[error("{0}: {1:#02X}")]
     DomainNameLabelInvalidChar(&'static str, u8),
@@ -89,7 +88,7 @@ pub enum Error {
     BadMessageType(MessageType),
 
     #[error("bad response code: {0}")]
-    BadResponseCode(ResponseCode),
+    BadResponseCode(RCodeValue),
 
     #[error("message is truncated")]
     MessageTruncated,
@@ -98,12 +97,12 @@ pub enum Error {
     NoAnswer,
 
     /// Resolver API is supported for a subset of record types
-    #[error("RType {0} is not supported")]
-    UnsupportedRType(RType),
+    #[error("Type {0} is not supported")]
+    UnsupportedType(Type),
 
     /// Resolver API is supported for a subset of record classes
-    #[error("RClass {0} is not supported")]
-    UnsupportedRClass(RClass),
+    #[error("Class {0} is not supported")]
+    UnsupportedClass(Class),
 
     /// Generic timeout error
     #[error("operation timed-out")]
@@ -116,6 +115,10 @@ pub enum Error {
     /// *rsdns* tries to avoid panics. InternalError is used instead.
     #[error("internal error: {0}")]
     InternalError(&'static str),
+
+    /// No nameservers found
+    #[error("no nameservers found")]
+    NoNameservers,
 }
 
 /// Result returned by [rsdns](crate).
